[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --local-branching-on-the-cheap
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


# Git and Software Freedom Conservancy
Git is a member project of [Software Freedom Conservancy](https://sfconservancy.org/). Conservancy is a not-for-profit organization that provides financial and administrative assistance to open source projects.
## Donation
Conservancy accepts donations on git's behalf. In the past, project money has typically gone to defraying travel costs for developers to come to our annual [GitTogether](https://git.wiki.kernel.org/index.php/GitTogether) mini-conference. A portion of the money goes to Conservancy to cover their operating expenses. You can also donate [directly](https://sfconservancy.org/donate) to Software Freedom Conservancy's general fund.
### Paypal
To donate to Git via PayPal:
![](https://www.paypal.com/en_US/i/scr/pixel.gif)
### Check
We can also accept donations drawn in USD from banks in the USA (donations from banks outside of the US or not in USD should be handled by wire). Make checks payable to "Software Freedom Conservancy, Inc." and place "Directed donation: Git" in the memo field. Checks should be mailed to:
```
  Software Freedom Conservancy, Inc.
  137 Montague ST STE 380
  BROOKLYN, NY 11201 USA

```

### Wire
Conservancy can accept wire donations, but the instructions vary depending on the country of origin. Please contact accounting@sfconservancy.org for instructions.
### Stock
Conservancy also accepts stock donations on behalf of the Git project. If you would like to donate stock, please contact accounting@sfconservancy.org for instructions on how to initiate the transfer.
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
